pub enum Effects {
Color,
Pulse,
Morph,
}Expand description
Available light effects.
As stated in the documentation, it appears that all the effect available in the Alienware Center are a combination of these.
Variants